__builtin__.object

Module __builtin__ :: Class object |
[show private | hide private]
[frames | no frames]

## Type object

Known Subclasses:
  `basestring`, `type`

The most base type

Method Summary
| ``__init__`(...)` x.__init__(...) initializes x; see x.__class__.__doc__ for signature
| ``__delattr__`(...)` x.__delattr__('name') <==> del x.name
| ``__getattribute__`(...)` x.__getattribute__('name') <==> x.name
| ``__hash__`(x)` x.__hash__() <==> hash(x)
| ``__new__`(T, S, ...)` T.__new__(S, ...) -> a new object with type S, a subtype of T
| ``__reduce__`(...)` helper for pickle
| ``__reduce_ex__`(...)` helper for pickle
| ``__repr__`(x)` x.__repr__() <==> repr(x)
| ``__setattr__`(...)` x.__setattr__('name', value) <==> x.name = value
| ``__str__`(x)` x.__str__() <==> str(x)

Class Variable Summary
`type` | `__class__` = `__builtin__.type`

Method Details

### __init__(...) (Constructor) x.__init__(...) initializes x; see x.__class__.__doc__ for signature

### __delattr__(...) x.__delattr__('name') <==> del x.name

### __getattribute__(...) x.__getattribute__('name') <==> x.name

    ### __hash__(x) (Hashing function) x.__hash__() <==> hash(x) Returns:
        hash(x)

    ### __new__(T, S, ...) T.__new__(S, ...) -> a new object with type S, a subtype of T Returns:
        a new object with type S, a subtype of T

### __reduce__(...) helper for pickle

### __reduce_ex__(...) helper for pickle

    ### __repr__(x) (Representation operator) x.__repr__() <==> repr(x) Returns:
        repr(x)

### __setattr__(...) x.__setattr__('name', value) <==> x.name = value

    ### __str__(x) (Informal representation operator) x.__str__() <==> str(x) Returns:
        str(x)

Generated by Epydoc 2.1 on Sat Sep 30 00:54:37 2006 | http://epydoc.sf.net